#
# spec file for package bnd-maven-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bnd-maven-plugin
Version:        6.3.1
Release:        2.2
Summary:        BND Maven plugin
# Part of jpm is under BSD, but jpm is not included in binary RPM
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://bnd.bndtools.org/
Source0:        bnd-%{version}.tar.xz
Patch1:         0001-Disable-removed-commands.patch
Patch2:         0002-Port-to-OSGI-7.0.0.patch
Patch3:         0003-Remove-unmet-dependencies.patch
Patch4:         reproducible-timestamps.patch
Patch5:         reproducible-packages-list.patch
BuildRequires:  fdupes
BuildRequires:  maven-local
BuildRequires:  mvn(biz.aQute.bnd:biz.aQute.bndlib) >= %{version}
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.shared:maven-mapping)
BuildRequires:  mvn(org.codehaus.plexus:plexus-component-metadata)
BuildArch:      noarch

%description
Collection of various Maven plugins provided by the Bnd project.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Libraries/Java

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n bnd-%{version}

%patch -P 1 -p1
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1

cp -r biz.aQute.bnd.maven/src/aQute/bnd/maven/lib/configuration maven/bnd-maven-plugin/src/main/java/aQute/bnd/maven/lib
cp -r biz.aQute.bnd.maven/src/aQute/bnd/maven/lib/executions maven/bnd-maven-plugin/src/main/java/aQute/bnd/maven/lib
pushd maven
%pom_remove_dep -r :biz.aQute.bnd.maven
# Unavailable reactor dependency - org.osgi.impl.bundle.repoindex.cli
%pom_disable_module bnd-indexer-maven-plugin
# Requires unbuilt parts of bnd
%pom_disable_module bnd-export-maven-plugin
%pom_disable_module bnd-reporter-maven-plugin
%pom_disable_module bnd-resolver-maven-plugin
%pom_disable_module bnd-run-maven-plugin
%pom_disable_module bnd-testing-maven-plugin
# Integration tests require Internet access
%pom_remove_plugin -r :maven-invoker-plugin
%pom_remove_plugin -r :maven-javadoc-plugin

%pom_remove_plugin -r :flatten-maven-plugin

%pom_remove_dep -r org.junit:junit-bom

%{mvn_package} biz.aQute.bnd:bnd-plugin-parent __noinstall
popd

%build
pushd maven
%{mvn_build} -f -- -Dproject.build.sourceEncoding=UTF-8 -Dsource=8
popd

%install
pushd maven
%mvn_install
popd
%fdupes -s %{buildroot}%{_javadocdir}

%files -f maven/.mfiles
%license LICENSE

%files javadoc -f maven/.mfiles-javadoc
%license LICENSE

%changelog
* Tue Feb 20 2024 Fridrich Strba <fstrba@suse.com>
- Use %%patch -P N instead of deprecated %%patchN.
* Mon Sep 18 2023 Fridrich Strba <fstrba@suse.com>
- Update to aqute-bnd 6.3.1
  * https://github.com/bndtools/bnd/wiki/Changes-in-6.3.1
  * https://github.com/bndtools/bnd/wiki/Changes-in-6.3.0
  * https://github.com/bndtools/bnd/wiki/Changes-in-6.2.0
  * https://github.com/bndtools/bnd/wiki/Changes-in-6.1.0
  * https://github.com/bndtools/bnd/wiki/Changes-in-6.0.0
  * https://github.com/bndtools/bnd/wiki/Changes-in-5.3.0
- Modified patches:
  * 0001-Disable-removed-commands.patch
  * 0003-Port-to-OSGI-7.0.0.patch -> 0002-Port-to-OSGI-7.0.0.patch
  * 0004-maven-plugin-dependencies.patch ->
    0003-Remove-unmet-dependencies.patch
  * reproducible-timestamps.patch
  * reproducible-packages-list.patch
    + rediff to changed context
- Removed patch:
  * aqute-bnd-java8compat.patch
    + handled by release=8 in ant javac task
* Sat Sep 16 2023 Fridrich Strba <fstrba@suse.com>
- Added patches:
  * reproducible-timestamps.patch
    + set "-reproducible" option to true by default
    + use SOURCE_DATE_EPOCH for timestamp if available
  * reproducible-packages-list.patch
    + make the order of packages to import/export deterministic
* Wed Apr 26 2023 Fridrich Strba <fstrba@suse.com>
- Fetch sources using source_service and don't distribute legally
  spurious files (bsc#1210878)
* Wed Nov 10 2021 Fridrich Strba <fstrba@suse.com>
- Update to aqute-bnd 5.1.1
  * ant plugin is in separate artifact
- Removed patch:
  * 0002-Fix-ant-compatibility.patch
    + fixed by upstream
* Tue Oct 19 2021 Fridrich Strba <fstrba@suse.com>
- Modified patches:
  * 0001-Disable-removed-commands.patch
  * 0002-Fix-ant-compatibility.patch
  * 0001-Port-to-OSGI-7.0.0.patch -> 0003-Port-to-OSGI-7.0.0.patch
    + rediff to changed context
- Added patch:
  * 0004-maven-plugin-dependencies.patch
    + Do not build a whole artifact, if we need only one source file
* Mon Oct 18 2021 Fridrich Strba <fstrba@suse.com>
- Added patch:
  + aqute-bnd-java8compat.patch
    + Produce bytecode compatible with Java 8
* Thu Feb 18 2021 Marcel Witte <wittemar@googlemail.com>
- Update to aqute-bnd 5.1.1
- Removed patch:
  * aqute-bnd-3.5.0-java8compat.patch
* Wed Apr  1 2020 Fridrich Strba <fstrba@suse.com>
- Addes patch:
  * 0001-Port-to-OSGI-7.0.0.patch
    + Port to OSGI 7.0.0
* Wed Apr  3 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of the bnd-maven-plugin distributed as a part
  of aqute-bnd 3.5.0
